@@ -1,7 +1,7 @@
 /*
  *  Authors: Rodney Dawes <dobey@ximian.com>
  *
- *  Copyright 2003-2004 Novell, Inc. (www.novell.com)
+ *  Copyright 2003-2006 Novell, Inc. (www.novell.com)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of version 2 of the GNU General Public License
@@ -27,24 +27,32 @@ GnomeWPInfo * gnome_wp_info_new (const gchar * uri,
   GnomeWPInfo * new;
   GnomeVFSFileInfo * info;
   GnomeVFSResult result;
+  gchar * escaped_path;
 
   info = gnome_vfs_file_info_new ();
-  result = gnome_vfs_get_file_info (gnome_vfs_escape_path_string (uri), info,
+  escaped_path = gnome_vfs_escape_path_string (uri);
+
+  result = gnome_vfs_get_file_info (escaped_path, info,
 				    GNOME_VFS_FILE_INFO_DEFAULT |
 				    GNOME_VFS_FILE_INFO_GET_MIME_TYPE |
 				    GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
   if (info == NULL || info->mime_type == NULL || result != GNOME_VFS_OK) {
     if (!strcmp (uri, "(none)")) {
+      gchar * md5sum;
+
       new = g_new0 (GnomeWPInfo, 1);
 
       new->mime_type = g_strdup ("image/x-no-data");
       new->uri = g_strdup (uri);
 
+      md5sum = gnome_thumbnail_md5 (escaped_path);
+
       new->thumburi = g_strconcat (g_get_home_dir (),
 				   "/.thumbnails/normal/",
-				   gnome_thumbnail_md5 (gnome_vfs_escape_path_string (uri)),
+				   md5sum,
 				   ".png",
 				   NULL);
+      g_free (md5sum);
 
       new->name = g_strdup (_("No Wallpaper"));
 
@@ -58,14 +66,20 @@ GnomeWPInfo * gnome_wp_info_new (const gchar * uri,
     new->uri = g_strdup (uri);
 
     new->thumburi = gnome_thumbnail_factory_lookup (thumbs,
-						    gnome_vfs_escape_path_string (new->uri),
+						    escaped_path,
 						    info->mtime);
     if (new->thumburi == NULL) {
+      gchar * md5sum;
+
+      md5sum = gnome_thumbnail_md5 (escaped_path);
+
       new->thumburi = g_strconcat (g_get_home_dir (),
 				   "/.thumbnails/normal/",
-				   gnome_thumbnail_md5 (gnome_vfs_escape_path_string (uri)),
+				   md5sum,
 				   ".png",
 				   NULL);
+
+      g_free (md5sum);
     }
     new->name = g_strdup (info->name);
     new->mime_type = g_strdup (info->mime_type);
@@ -73,6 +87,7 @@ GnomeWPInfo * gnome_wp_info_new (const gchar * uri,
     new->size = info->size;
     new->mtime = info->mtime;
   }
+  g_free (escaped_path);
   gnome_vfs_file_info_unref (info);
 
   return new;
