@@ -209,13 +209,13 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 	
 	if (path && len > 7 && ( (!strcmp (path + len - 7, ".tar.gz")) || (!strcmp (path + len - 4, ".tgz")) )) {
 		filename = g_shell_quote (path);
-		command = g_strdup_printf ("sh -c '/bin/gzip -d -c < \"%s\" | /bin/tar ft -  | head -1'",
+		command = g_strdup_printf ("sh -c '/bin/gzip -d -c < \"%s\" | /bin/tar ft -  | head -n 1'",
 					    filename);
 		theme_props->filetype=TARGZ;
 		g_free (filename);
 	} else if (path && len > 8 && !strcmp (path + len - 8, ".tar.bz2")) {
 		filename = g_shell_quote (path);
-		command = g_strdup_printf ("sh -c '/usr/bin/bzip2 -d -c < \"%s\" | /bin/tar ft - | head -1'",
+		command = g_strdup_printf ("sh -c '/usr/bin/bzip2 -d -c < \"%s\" | /bin/tar ft - | head -n 1'",
 					    filename);
 		theme_props->filetype=TARBZ;
 		g_free (filename);
@@ -235,8 +235,6 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 	
 	
 	if ((gnome_vfs_make_directory(theme_props->target_tmp_dir,0700)) != GNOME_VFS_OK) {
-		GtkWidget *dialog;
-				
 		dialog = gtk_message_dialog_new (NULL,
 						GTK_DIALOG_MODAL,
 						GTK_MESSAGE_ERROR,
@@ -255,8 +253,6 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 	
 	if (theme_props->filetype == TARBZ ) {
 		if (!g_file_test ("/usr/bin/bzip2", G_FILE_TEST_EXISTS)) {
-			GtkWidget *dialog;
-				
 			dialog = gtk_message_dialog_new (NULL,
 						GTK_DIALOG_MODAL,
 						GTK_MESSAGE_ERROR,
@@ -273,8 +269,6 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 		}
 		
 		if (!transfer_done_tarbz2_idle_cb(theme_props)) {
-			GtkWidget *dialog;
-				
 			dialog = gtk_message_dialog_new (NULL,
 							GTK_DIALOG_MODAL,
 							GTK_MESSAGE_ERROR,
@@ -293,8 +287,6 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 	
 	if (theme_props->filetype == TARGZ ) {
 		if (!g_file_test ("/bin/gzip", G_FILE_TEST_EXISTS)) {
-			GtkWidget *dialog;
-
 			dialog = gtk_message_dialog_new (NULL,
 						GTK_DIALOG_MODAL,
 						GTK_MESSAGE_ERROR,
@@ -310,8 +302,6 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 			return;	
 		}
 		if (!transfer_done_targz_idle_cb(theme_props)) {
-			GtkWidget *dialog;
-				
 			dialog = gtk_message_dialog_new (NULL,
 							GTK_DIALOG_MODAL,
 							GTK_MESSAGE_ERROR,
@@ -348,8 +338,6 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 			theme_props->target_dir = g_strdup_printf("%s/.themes/%s",g_get_home_dir(),dir[0]);
 			theme_props->user_message=g_strdup_printf(_("Controls Theme %s correctly installed.\nYou can select it in the theme details."),dir[0]);
 		} else if (theme_type == THEME_ENGINE) {
-			GtkWidget *dialog;
-
 			dialog = gtk_message_dialog_new (NULL,
 			  	       GTK_DIALOG_MODAL,
 				       GTK_MESSAGE_ERROR,
@@ -365,8 +353,6 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 			g_free (command);
 			return;	
 		} else {
-			GtkWidget *dialog;
-				
 			dialog = gtk_message_dialog_new (NULL,
 			  	       GTK_DIALOG_MODAL,
 				       GTK_MESSAGE_ERROR,
@@ -390,8 +376,6 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 								GNOME_VFS_XFER_ERROR_MODE_ABORT,
 								GNOME_VFS_XFER_OVERWRITE_MODE_REPLACE,
 								NULL,NULL) != GNOME_VFS_OK) {
-			GtkWidget *dialog;
-				
 			dialog = gtk_message_dialog_new (NULL,
 						GTK_DIALOG_MODAL,
 						GTK_MESSAGE_ERROR,
@@ -409,8 +393,6 @@ transfer_done_cb (GtkWidget *dlg, gchar *path)
 			g_free (command);
 			return;	
 		} else {
-			GtkWidget *dialog;
-						
 			dialog = gtk_message_dialog_new (NULL,
 			  	       GTK_DIALOG_MODAL,
 				       GTK_MESSAGE_INFO,
@@ -441,7 +423,7 @@ install_dialog_response (GtkWidget *widget, int response_id, gpointer data)
 {
 	GladeXML *dialog = data;
 	GtkWidget *dlg;
-	gchar *filename, *path, *base;
+	gchar *filename, *path, *base, *scheme;
 	GList *src, *target;
 	GnomeVFSURI *src_uri;
 	const gchar *raw;
@@ -471,10 +453,12 @@ install_dialog_response (GtkWidget *widget, int response_id, gpointer data)
 			return;
 		}
 
-		if (strncmp (raw, "http://", 7) && strncmp (raw, "ftp://", 6) && *raw != '/')
+		if ((scheme = gnome_vfs_get_uri_scheme (raw)) == NULL && *raw != '/')
 			filename = gnome_file_entry_get_full_path (GNOME_FILE_ENTRY (WID ("install_theme_picker")), TRUE);
 		else
 			filename = g_strdup (raw);
+		g_free (scheme);
+		
 		if (filename == NULL)	{
 			GtkWidget *dialog;
 
@@ -598,15 +582,15 @@ gnome_theme_installer_run (GtkWidget *parent, gchar *filename)
 	running_theme_install = TRUE;
 
 	if (!g_file_test ("/bin/tar", G_FILE_TEST_EXISTS)) {
-		GtkWidget *dialog;
+		GtkWidget *error_dialog;
 
-		dialog = gtk_message_dialog_new (NULL,
+		error_dialog = gtk_message_dialog_new (NULL,
 						GTK_DIALOG_MODAL,
 						GTK_MESSAGE_ERROR,
 						GTK_BUTTONS_OK,
 						_("Cannot install theme.\nThe tar program is not installed on your system."));
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
+		gtk_dialog_run (GTK_DIALOG (error_dialog));
+		gtk_widget_destroy (error_dialog);
 		return;
 	}
 
